widgets

package
v1.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AlertBox

func AlertBox(screen Screen, title, text string, width, height int)

func InputBox

func InputBox(screen Screen, text string) string

func SelectBox

func SelectBox(screen Screen, title string, values []string) string

func TitledWindow

func TitledWindow(screen Screen, title string, width, height, x, y int) (*curses.Window, *curses.Window)

Types

type Progress

type Progress struct {
	// contains filtered or unexported fields
}

func ProgressBar

func ProgressBar(screen Screen, title string, min int, max int, curr int) Progress

Jump to